Struct UARTConsole
Source struct UARTConsole {
uart: Arc<dyn SerialDriver>,
}
向控制台写入字符串
从控制台读取一个字符
从控制台读取一行字符串,直到遇到换行符
刷新控制台输出缓冲区
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.