Struct IrqManager
Source pub struct IrqManager {
root: bool,
mapping: BTreeMap<usize, Vec<Arc<dyn Driver>>>,
all: Vec<Arc<dyn Driver>>,
}
中断号到驱动程序列表的映射
每个中断号可以对应多个驱动程序
创建一个新的中断管理器
参数:
返回值:
新创建的中断管理器实例
注册中断号与驱动程序的映射
参数:
irq - 中断号
driver - 要注册的驱动程序
注册可选的中断号与驱动程序的映射
参数:
irq_opt - 可选的中断号
driver - 要注册的驱动程序
注销中断号与驱动程序的映射
参数:
irq - 要注销的中断号
driver - 要注销的驱动程序
处理中断
参数:
返回值:
如果中断被处理则返回 true,否则返回 false
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.