Struct SharedMemoryTable
Source pub struct SharedMemoryTable {
memory: Vec<Arc<SharedMemory>>,
}
简单移除(若还被其他地方持有 Arc,不会真正释放)
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.