pub struct Capabilities(<Capabilities as PublicFlags>::Internal);Expand description
Linux 能力位标志
这些标志代表了内核中各种特权操作的权限。 在单 root 用户系统中,所有进程默认拥有所有能力。
Tuple Fields
0: <Capabilities as PublicFlags>::InternalImplementations
Sourceimpl Capabilities
impl Capabilities
Sourcepub const DAC_OVERRIDE: Self
pub const DAC_OVERRIDE: Self
绕过文件读写执行权限检查
Sourcepub const DAC_READ_SEARCH: Self
pub const DAC_READ_SEARCH: Self
绕过文件读权限检查
Sourcepub const LINUX_IMMUTABLE: Self
pub const LINUX_IMMUTABLE: Self
设置不可变标志
Sourcepub const NET_BIND_SERVICE: Self
pub const NET_BIND_SERVICE: Self
绑定特权端口 (<1024)
Sourcepub const NET_BROADCAST: Self
pub const NET_BROADCAST: Self
网络广播
Sourcepub const SYS_MODULE: Self
pub const SYS_MODULE: Self
加载/卸载内核模块
Sourcepub const SYS_CHROOT: Self
pub const SYS_CHROOT: Self
使用 chroot()
Sourcepub const SYS_PTRACE: Self
pub const SYS_PTRACE: Self
使用 ptrace()
Sourcepub const SYS_RESOURCE: Self
pub const SYS_RESOURCE: Self
覆盖资源限制
Sourcepub const SYS_TTY_CONFIG: Self
pub const SYS_TTY_CONFIG: Self
配置 TTY
Sourcepub const AUDIT_WRITE: Self
pub const AUDIT_WRITE: Self
写入审计日志
Sourcepub const AUDIT_CONTROL: Self
pub const AUDIT_CONTROL: Self
配置审计
Sourcepub const MAC_OVERRIDE: Self
pub const MAC_OVERRIDE: Self
覆盖 MAC 策略
Sourcepub const WAKE_ALARM: Self
pub const WAKE_ALARM: Self
触发唤醒告警
Sourcepub const BLOCK_SUSPEND: Self
pub const BLOCK_SUSPEND: Self
阻止系统挂起
Sourcepub const AUDIT_READ: Self
pub const AUDIT_READ: Self
读取审计日志
Sourcepub const CHECKPOINT_RESTORE: Self
pub const CHECKPOINT_RESTORE: Self
检查点/恢复
Sourceimpl Capabilities
impl Capabilities
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl Capabilities
impl Capabilities
Sourcepub const fn iter(&self) -> Iter<Capabilities>
pub const fn iter(&self) -> Iter<Capabilities>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Capabilities>
pub const fn iter_names(&self) -> IterNames<Capabilities>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.