Struct TidAllocator
Source pub struct TidAllocator {
next_tid: AtomicU32,
}
简单的任务ID分配器。
每次调用allocate方法时,都会返回一个唯一的任务ID。
任务ID从1开始递增。
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.