Struct WorkQueue
Source pub struct WorkQueue {
sleeping: usize,
worker: Vec<Arc<SpinLock<Task>>>,
work_queue: VecDeque<WorkItem>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.