Struct TimerEntries
Source pub struct TimerEntries {
pub entries: BTreeMap<usize, TimerEntry>,
}
向集合中添加一个定时器条目
参数:
trigger_time: 触发时间点
entry: 定时器条目
查找与指定任务关联的定时器条目
参数:
返回值:
移除与指定任务关联的定时器条目
参数:
返回值:
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.