Struct FrameTracker
Source pub struct FrameTracker(Ppn);
物理帧跟踪器。
实现了 RAII 模式:当此结构体被 drop 时,它所管理的物理页帧会被自动回收。
创建一个新的 FrameTracker。
在创建时,会自动将该物理页帧清零。
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.