Struct MmapFile
Source pub struct MmapFile {
pub file: Arc<dyn File>,
pub offset: usize,
pub len: usize,
pub prot: ProtFlags,
pub flags: MapFlags,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.