Struct NetRxToken
Source pub struct NetRxToken<'a> {
buffer: &'a [u8],
}
Consumes the token to receive a single network packet.
Read more
The Packet ID associated with the frame received by this [RxToken]
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.