Struct NetTxToken
Source pub struct NetTxToken<'a> {
device: &'a Arc<dyn NetDevice>,
}
Consumes the token to send a single network packet.
Read more
The Packet ID to be associated with the frame to be transmitted by this [TxToken].
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.