pub struct SysMountFlags(<SysMountFlags as PublicFlags>::Internal);Expand description
mount 系统调用标志位(与 Linux ABI 完全一致)
参考:include/uapi/linux/mount.h 这些标志在当前实现中会被忽略,但保留以保持 ABI 兼容性
Tuple Fields
0: <SysMountFlags as PublicFlags>::InternalImplementations
Sourceimpl SysMountFlags
impl SysMountFlags
Sourcepub const MS_SYNCHRONOUS: Self
pub const MS_SYNCHRONOUS: Self
同步所有写入
Sourcepub const MS_REMOUNT: Self
pub const MS_REMOUNT: Self
重新挂载(修改挂载选项)
Sourcepub const MS_MANDLOCK: Self
pub const MS_MANDLOCK: Self
允许强制锁
Sourcepub const MS_DIRSYNC: Self
pub const MS_DIRSYNC: Self
目录同步
Sourcepub const MS_NOSYMFOLLOW: Self
pub const MS_NOSYMFOLLOW: Self
不跟随符号链接
Sourcepub const MS_NOATIME: Self
pub const MS_NOATIME: Self
不更新访问时间
Sourcepub const MS_NODIRATIME: Self
pub const MS_NODIRATIME: Self
不更新目录访问时间
Sourcepub const MS_RELATIME: Self
pub const MS_RELATIME: Self
相对访问时间
Sourcepub const MS_STRICTATIME: Self
pub const MS_STRICTATIME: Self
严格的访问时间
Sourcepub const MS_LAZYTIME: Self
pub const MS_LAZYTIME: Self
延迟更新时间
Sourceimpl SysMountFlags
impl SysMountFlags
Sourcepub const fn bits(&self) -> u64
pub const fn bits(&self) -> u64
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u64) -> Option<Self>
pub const fn from_bits(bits: u64) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u64) -> Self
pub const fn from_bits_truncate(bits: u64) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u64) -> Self
pub const fn from_bits_retain(bits: u64) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in a source flags value are also set in a target flags value.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in a source flags value are also set in a target flags value.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in two flags values.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in two flags values.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of a source flags value with the complement of a target flags
value (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in two flags values.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in a flags value, truncating the result.
Sourceimpl SysMountFlags
impl SysMountFlags
Sourcepub const fn iter(&self) -> Iter<SysMountFlags>
pub const fn iter(&self) -> Iter<SysMountFlags>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<SysMountFlags>
pub const fn iter_names(&self) -> IterNames<SysMountFlags>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.