SaFlags

Struct SaFlags 

#[repr(transparent)]
pub struct SaFlags(<SaFlags as PublicFlags>::Internal);
信号处理行为标志,用于 sigaction 系统调用。

Tuple Fields

0: <SaFlags as PublicFlags>::Internal

Implementations

Source

impl SaFlags

pub const NOCLDSTOP: Self

阻止 SIGCHLD 在子进程停止时生成。

pub const NOCLDWAIT: Self

在 SIGCHLD 上设置,以禁止僵尸进程 (子进程退出时不产生僵尸进程)。

pub const SIGINFO: Self

使用 siginfo_t 结构体传递信号详细信息 (开启实时信号行为,使用三参数处理器)。

pub const ONSTACK: Self

表示将使用已注册的备用信号栈 (sigaltstack)。

pub const RESTART: Self

标志,使得被中断的慢速系统调用在信号处理函数返回后自动重新启动。

pub const NODEFER: Self

防止当前信号在处理函数执行期间被自动阻塞 (即,不自动添加到屏蔽字)。

pub const RESETHAND: Self

清除信号处理函数:信号在投递后,其处理函数被重置为 SIG_DFL。

pub const UNSUPPORTED: Self

不受支持的标志位。用于用户空间检测内核对标志位的支持情况。

pub const EXPOSE_TAGBITS: Self

暴露架构定义的标签位(tag bits)到 siginfo.si_addr 中。

pub const NOMASK: Self

历史上的 SA_NOMASK 名称,等同于 SA_NODEFER。

pub const ONESHOT: Self

历史上的 SA_ONESHOT 名称,等同于 SA_RESETHAND.

Source

impl SaFlags

pub const fn empty() -> Self

Get a flags value with all bits unset.

pub const fn all() -> Self

Get a flags value with all known bits set.

pub const fn bits(&self) -> u32

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u32) -> Option<Self>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u32) -> Self

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u32) -> Self

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Self>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Self) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Self) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Self)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Self)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Self)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Self, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Self) -> Self

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Self) -> Self

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Self) -> Self

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Self) -> Self

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Self

The bitwise negation (!) of the bits in a flags value, truncating the result.

Source

impl SaFlags

pub const fn iter(&self) -> Iter<SaFlags>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<SaFlags>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.

Source

impl SaFlags

pub fn is_supported(&self) -> bool

检查标志位是否在当前内核支持的范围内

pub fn is_known(&self) -> bool

检查标志位是否在已知标志范围内